# Autogenerated file
def render(note):
    yield """<li class=\"note col-xs-12 col-sm-6 col-lg-4\">
  <div class=\"panel panel-primary\">
    <div class=\"panel-heading\">
      """
    yield str(note[0])
    yield """
      <a
        class=\"btn btn-danger btn-xs archive-note pull-right\"
        data-note=\""""
    yield str(note[0])
    yield """\"
        href=\"archive/"""
    yield str(note[0])
    yield """\">&times;</a>
    </div>
    <div class=\"panel-body\">
      """
    yield str(note[2])
    yield """
    </div>
  </div>
</li>
"""
