# Autogenerated file
def render(notes):
    yield """<!DOCTYPE html>
<html lang=\"en\">
  <head>
    <meta charset=\"utf-8\">
    <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge\">
    <meta name=\"viewport\" content=\"width=device-width, initial-scale=1\">
    <title>Notes</title>
    <link href=\"//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css\" rel=\"stylesheet\">
    <link href=\"css/site.css\" rel=\"stylesheet\">
    <script src=\"//code.jquery.com/jquery-1.11.0.min.js\"></script>
    <script src=\"//netdna.bootstrapcdn.com/bootstrap/3.1.1/js/bootstrap.min.js\"></script>
    <script src=\"//imagesloaded.desandro.com/imagesloaded.pkgd.min.js\"></script>
    <script src=\"//masonry.desandro.com/masonry.pkgd.min.js\"></script>
    <script src=\"static/js/notes.js\"></script>
    <script type=\"text/javascript\">
      $(function() """
    yield """{
        new Notes.Editor();
      });
    </script>
  </head>
  <body>
    <div class=\"container content\">
      <div class=\"page-header\">
        <h1>Notes</h1>
      </div>
      <form action=\".\" class=\"form\" id=\"note-form\" method=\"post\">
        <button class=\"btn btn-primary btn-xs\" type=\"submit\">
          <span class=\"glyphicon glyphicon-plus\"></span> Add Note
        </button>
        <textarea class=\"form-control\" id=\"content\" name=\"content\"></textarea>
      </form>
      <br />
      <ul class=\"list-unstyled notes\">
        """
    for note in notes:
        yield """          """
# Autogenerated file
        def render1(note):
            yield """<li class=\"note col-xs-12 col-sm-6 col-lg-4\">
  <div class=\"panel panel-primary\">
    <div class=\"panel-heading\">
      """
            yield str(note[0])
            yield """
      <a
        class=\"btn btn-danger btn-xs archive-note pull-right\"
        data-note=\""""
            yield str(note[0])
            yield """\"
        href=\"archive/"""
            yield str(note[0])
            yield """\">&times;</a>
    </div>
    <div class=\"panel-body\">
      """
            yield str(note[2])
            yield """
    </div>
  </div>
</li>
"""
        yield from render1(note)
        yield """        """
    yield """      </ul>
      <div style=\"clear:both;\"></div>
    </div>
  </body>
</html>"""
